@@ -70,7 +70,8 @@ def validate_group_handle(doc):
     """
     util.validate_doc(
         doc=doc,
-        mandatory=['id', 'name', 'workflow', 'members', 'parameters', 'files']
+        mandatory=['id', 'name', 'workflow', 'members', 'parameters', 'files'],
+        optional=['runs']
     )
 
 
@@ -316,7 +317,7 @@ def validate_workflow_handle(doc):
     util.validate_doc(
         doc=doc,
         mandatory=mandatory,
-        optional=['postproc', 'outputs']
+        optional=['groups', 'postproc', 'outputs']
     )
     # Validate the post-processing run handle if present
     if 'postproc' in doc:
